@@ -27,7 +27,8 @@ class File(BaseFile):
 
         filename (str):  This is the name of the uploaded file
         file_id:   This is the generated UUID for the uploaded file
-        path:            This is a  compination of `upload_storage` and `file_id` separated by
+        upload_storage:   Name of the storage used to save the uploaded file
+        path:            This is a  combination of `upload_storage` and `file_id` separated by
                         `/`. This will be use later to retrieve the file
         content_type:   This is the content type of the uploaded file
         uploaded_at (datetime):    This is the upload date in ISO format
@@ -42,8 +43,9 @@ class File(BaseFile):
         content: Any,
         filename: Optional[str] = None,
         content_type: Optional[str] = None,
+        **kwargs: Dict[str, Any],
     ) -> None:
-        super().__init__()
+        super().__init__(**kwargs)
         if isinstance(content, dict):
             object.__setattr__(self, "original_content", None)
             object.__setattr__(self, "saved", True)
@@ -82,12 +84,15 @@ class File(BaseFile):
 
     def save_to_storage(self, upload_storage: Optional[str] = None) -> None:
         """Save current file into provided `upload_storage`"""
+        metadata = self.get("metadata", {})
+        metadata.update({"filename": self.filename, "content_type": self.content_type})
         stored_file = self.store_content(
             self.original_content,
             upload_storage,
-            metadata={"filename": self.filename, "content_type": self.content_type},
+            metadata=metadata,
         )
         self["file_id"] = stored_file.name
+        self["upload_storage"] = upload_storage
         self["uploaded_at"] = datetime.utcnow().isoformat()
         self["path"] = "%s/%s" % (upload_storage, stored_file.name)
         self["url"] = stored_file.get_cdn_url()
